@@ -7,6 +7,9 @@ describe 'sahara::client' do
 
   shared_examples_for 'sahara client' do
 
+    it { is_expected.to contain_class('sahara::deps') }
+    it { is_expected.to contain_class('sahara::params') }
+
     context 'with default parameters' do
       it { is_expected.to contain_package('python-saharaclient').with(
         :ensure => 'present',
@@ -27,6 +30,7 @@ describe 'sahara::client' do
       }
     end
 
+    it { is_expected.to contain_class('openstacklib::openstackclient') }
   end
 
   on_supported_os({
@@ -40,11 +44,7 @@ describe 'sahara::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :client_package_name => 'python3-saharaclient' }
-          else
-            { :client_package_name => 'python-saharaclient' }
-          end
+          { :client_package_name => 'python3-saharaclient' }
         when 'RedHat'
           { :client_package_name => 'python-saharaclient' }
         end
