@@ -11,7 +11,13 @@ describe 'sahara::db::sync' do
           :path        => '/usr/bin',
           :user        => 'sahara',
           :refreshonly => 'true',
+          :try_sleep   => 5,
+          :tries       => 10,
           :logoutput   => 'on_failure',
+          :subscribe   => ['Anchor[sahara::install::end]',
+                           'Anchor[sahara::config::end]',
+                           'Anchor[sahara::dbsync::begin]'],
+          :notify      => 'Anchor[sahara::dbsync::end]',
           :tag         => 'openstack-db',
         )
       end
@@ -30,7 +36,13 @@ describe 'sahara::db::sync' do
           :path        => '/usr/bin',
           :user        => 'sahara',
           :refreshonly => 'true',
+          :try_sleep   => 5,
+          :tries       => 10,
           :logoutput   => 'on_failure',
+          :subscribe   => ['Anchor[sahara::install::end]',
+                           'Anchor[sahara::config::end]',
+                           'Anchor[sahara::dbsync::begin]'],
+          :notify      => 'Anchor[sahara::dbsync::end]',
           :tag         => 'openstack-db',
         )
         }
@@ -44,7 +56,6 @@ describe 'sahara::db::sync' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
